Changes
=======

Version 0.2.1
-------------

* Fix error when importing HTTPError.

Version 0.2
-------------

* Flickr and 500px support. Contribution by Francisco Morales.

Version 0.1.3
-------------

* Make the cache more fault-tolerant.

Version 0.1.2
-------------

* Fix readme code errors. 

Version 0.1.1
-------------

* Updated readme with some examples. 

Version 0.1
-------------

* Basic social network activity fetching with cache. 
